import { createWebHistory, createRouter } from 'vue-router'
import Layout from '@/layout'
import ParentView from '@/components/ParentView'

/**
 * Note: 路由配置项
 *
 * hidden: true                     // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true                 // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                  // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                  // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                  // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect             // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'               // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * query: '{"id": 1, "name": "ry"}' // 访问路由的默认传递参数
 * meta : {
    noCache: true                   // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'                  // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'                // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false               // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'      // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/',
    name: 'Home',
    component: () => import('../views/websiteLayout.vue'),
    hidden:true,
    children: [
      {
        path: 'login',
        name: 'login',
        component: () => import('../views/login.vue'),
        children: [
        ]
      },
      {
        path: '',
        component: () => import('../views/website/index/index.vue'),
      },
      {
        path: 'searchList/0',
        component: () => import('../views/website/searchList/index0.vue'),
      },
      {
        path: 'searchList/0/detail/:id',
        component: () => import('../views/website/searchList/index0Detail.vue'),
      },
      {
        path: 'searchList/1',
        component: () => import('../views/website/searchList/index1.vue'),
      },
      {
        path: 'searchList/1/detail/:id',
        component: () => import('../views/website/searchList/index1Detail.vue'),
      },
      {
        path: 'searchList/2',
        component: () => import('../views/website/searchList/index2.vue'),
      },
      {
        path: 'searchList/3',
        component: () => import('../views/website/searchList/index3.vue'),
      },
      {
        path: 'searchList/4',
        component: () => import('../views/website/searchList/index4.vue'),
      },
      {
        path: 'searchList/4/detail/:id',
        component: () => import('../views/website/searchList/index4Detail.vue'),
      },
      {
        path: 'solution/:name',
        name: 'solution',
        component: () => import('../views/website/solution/solution.vue'),
      },
      {
        path: 'solution/detail/:id',
        name: 'solutionDetail',
        component: () => import('../views/website/solution/detail.vue'),
      },
      {
        path: 'innovate',
        name: 'innovate',
        component: () => import('../views/website/innovate/innovate.vue'),
      },
      {
        path: 'innovate/detail/:id',
        name: 'innovateDetail',
        component: () => import('../views/website/innovate/detail.vue'),
      },
      {
        path: 'activity',
        name: 'activity',
        component: () => import('../views/website/activity/activity.vue'),
        children:[
          {
            path: '',
            name: 'activityList',
            component: () => import('../views/website/activity/list.vue'),
          },
          {
            path: 'detail/:id',
            name: 'activityDetail',
            component: () => import('../views/website/activity/detail.vue'),
          },
        ]
      },
      {
        path: 'about',
        name: 'about',
        component: () => import('../views/website/about/about.vue'),
      },
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login'),
    hidden: true
  },
  {
    path: '/register',
    component: () => import('@/views/register'),
    hidden: true
  },
  {
    path: "/:pathMatch(.*)*",
    component: () => import('@/views/error/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error/401'),
    hidden: true
  },
  {
    path: '/identity',
    component: () => import('@/views/identity/layout'),
    hidden:true,
    children:[
      {
        path:'index',
        component: () => import('@/views/identity/index'),
        name: 'index',
        meta: { title: '身份选择'},
      },
      {
        path:'enterprise',
        component: () => import('@/views/identity/enterprise'),
        name: 'enterprise',
        meta: { title: '企业入驻'}
      },
      {
        path:'expert',
        component: () => import('@/views/identity/expert'),
        name: 'expert',
        meta: { title: '专家入驻'}
      },
      {
        path:'research',
        component: () => import('@/views/identity/research'),
        name: 'research',
        meta: { title: '研究机构入驻'}
      },
      {
        path:'laboratory',
        component: () => import('@/views/identity/laboratory'),
        name: 'laboratory',
        meta: { title: '实验室入驻'}
      },
      {
        path:'agent',
        component: () => import('@/views/identity/agent'),
        name: 'agent',
        meta: { title: '科技经纪人入驻'}
      }
    ]
  },
  {
		path: '/admin',
		component: Layout,
		redirect: '/admin/index',
		children: [
			{
				path: 'index',
				component: () => import('@/views/admin/index'),
				name: 'Index',
				meta: { title: '首页', icon: 'dashboard', affix: true },
			},
		],
	},
  
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'profile',
        component: () => import('@/views/system/user/profile/index'),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      }
    ]
  },
  {
    path: '/system/user-auth',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'role/:userId(\\d+)',
        component: () => import('@/views/system/user/authRole'),
        name: 'AuthRole',
        meta: { title: '分配角色', activeMenu: '/system/user' }
      }
    ]
  },
  {
    path: '/system/role-auth',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'user/:roleId(\\d+)',
        component: () => import('@/views/system/role/authUser'),
        name: 'AuthUser',
        meta: { title: '分配用户', activeMenu: '/system/role' }
      }
    ]
  },
  {
    path: '/system/dict-data',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index/:dictId(\\d+)',
        component: () => import('@/views/system/dict/data'),
        name: 'Data',
        meta: { title: '字典数据', activeMenu: '/system/dict' }
      }
    ]
  },
  {
    path: '/monitor/job-log',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index',
        component: () => import('@/views/monitor/job/log'),
        name: 'JobLog',
        meta: { title: '调度日志', activeMenu: '/monitor/job' }
      }
    ]
  },
  {
    path: '/tool/gen-edit',
    component: Layout,
    hidden: true,
    children: [
      {
        path: 'index',
        component: () => import('@/views/tool/gen/editTable'),
        name: 'GenEdit',
        meta: { title: '修改生成配置', activeMenu: '/tool/gen' }
      }
    ]
  }
];

export const enterpriseRoutes = [
  {
    path: '/technology',
    component: Layout,
    meta: { title: '技术管理', icon: 'dashboard' },
    alwaysShow:true,
    redirect: 'noRedirect',
    children: [
      {
        path: 'achievement',
        component: ParentView,
        meta: { title: '成果列表', icon: 'list' },
        alwaysShow:true,
        redirect: 'noRedirect',
        children:[
          {
            path: 'release',
            component: () => import('@/views/admin/two/technology/release'),
            name: 'release',
            meta: { title: '发布成果', icon: 'dashboard' }
          }
        ]
      },
      {
        path: 'research',
        component: () => import('@/views/admin/two/technology/research'),
        name: 'Research',
        meta: { title: '科研项目列表', icon: 'dashboard' }
      }
    ]
  },
]

export const expertRoutes=[
  {
    path: '/account',
    component: Layout,
    meta: { title: '账号管理', icon: 'dashboard' },
    alwaysShow:true,
    redirect: 'noRedirect',
    children: [
      {
        path: 'bill',
        component: () => import('@/views/admin/two/account/bill'),
        name: 'Bill',
        meta: { title: '账单列表', icon: 'dashboard' }
      }
    ]
  },
  // {
  //   path: '/technology',
  //   component: Layout,
  //   meta: { title: '技术管理', icon: 'dashboard' },
  //   alwaysShow:true,
  //   redirect: 'noRedirect',
  //   children: [
  //     {
  //       path: 'achievement',
  //       component: ParentView,
  //       meta: { title: '成果列表', icon: 'list' },
  //       alwaysShow:true,
  //       redirect: 'noRedirect',
  //       children:[
  //         {
  //           path: 'release',
  //           component: () => import('@/views/admin/two/technology/release'),
  //           name: 'release',
  //           meta: { title: '发布成果', icon: 'dashboard' }
  //         }
  //       ]
  //     },
  //     {
  //       path: 'research',
  //       component: () => import('@/views/admin/two/technology/research'),
  //       name: 'Research',
  //       meta: { title: '科研项目列表', icon: 'dashboard' }
  //     }
  //   ]
  // },
]

export const researchRoutes=[
  {
    path: '/three',
    component: Layout,
    children: [
      {
        path: 'research',
        component: () => import('@/views/admin/three/index'),
        name: 'Research',
        meta: { title: '菜单3', icon: 'dashboard' }
      }
    ]
  },
]


const router = createRouter({
  history: createWebHistory(),
  routes: constantRoutes,
  scrollBehavior(to, from, savedPosition) {
    if (savedPosition) {
      return savedPosition
    } else {
      return { top: 0 }
    }
  },
});

export default router;